# anime-episode-parser

try parse episode info from title

```bash
poetry add anime_episode_parser
```

```python
from anime_episode_parser import parse_episode

print(parse_episode('[YMDR][哥布林殺手][Goblin Slayer][2018][01][1080p][AVC][JAP][BIG5][MP4-AAC][繁中]'))
```
